@@ -25,7 +25,7 @@ class WebBrowser:
       downloadDir = os.path.join(current_path, 'ToKkai')
     if not os.path.exists(self.downloadDir):
       os.makedirs(self.downloadDir, exist_ok = True)
-      self.logger.debug("Directory '%s' created" % self.downloadDir)
+      self.logger.info("Directory '%s' created" % self.downloadDir)
 
     # File Chrome
     if (os.path.exists('C:\\Program Files (x86)\\Google\\Chrome\\Application\\chrome.exe')):
@@ -446,7 +446,7 @@ class WebBrowser:
 
       if not '@' in search_value and ghi_nhan:
         # Click 'Dong'
-        search = self.searchClick('Nut Dong', 'XPATH', '//button[@aria-label="Close dialog"]', 6, 3, 2)
+        search = self.searchClick('Nut Dong', 'XPATH', '//button[@aria-label="Close dialog"]', 6, 5, 2)
         if search:
           self.logger.info("Da hoan thanh")
           status = "xong"
